@@ -1,10 +1,10 @@
 import tkinter as tk
-from pyrustic.viewable import Viewable
-from pyrustic import tkmisc
+from pyrustic.view import View
 
 
-class FailureView(Viewable):
+class FailureView(View):
     def __init__(self, master, main_view, main_host, data):
+        super().__init__()
         self._master = master
         self._main_view = main_view
         self._main_host = main_host
@@ -23,13 +23,3 @@ class FailureView(Viewable):
         # button quit
         button = tk.Button(self._body, text="Close", command=self.destroy)
         button.pack(anchor="e", padx=2, pady=2)
-
-    def _on_display(self):
-        pass
-
-    def _on_destroy(self):
-        pass
-
-    def _toplevel_geometry(self):
-        super()._toplevel_geometry()
-        tkmisc.dialog_effect(self._body)
