@@ -1,18 +1,51 @@
-from pyrustic.viewable import Viewable
+from pyrustic.view import View
 from pyrustic.widget.confirm import Confirm
 from pyrustic.widget.toast import Toast
-from pyrustic import tkmisc
 import tkinter as tk
 import os.path
 from hubway.view.failure_view import FailureView
 
 
-class PublishingView(Viewable):
-    def __init__(self, master, main_view, main_host, asset_version):
+TEXT = """\
+Install [Hubstore]({hubstore_link}):
+
+```bash
+$ pip install hubstore
+```
+
+or upgrade Hubstore:
+
+```bash
+$ pip install hubstore --upgrade --upgrade-strategy eager
+```
+
+
+Run Hubstore:
+
+```bash
+$ hubstore
+```
+
+
+Then paste or type this in Hubstore:
+
+`{owner}/{repo}`
+
+
+Enjoy !
+
+
+
+Published with [Pyrustic]({pyrustic_link})
+"""
+
+class PublishingView(View):
+    def __init__(self, master, main_view, main_host, asset_name):
+        super().__init__()
         self._master = master
         self._main_view = main_view
         self._main_host = main_host
-        self._asset_version = asset_version
+        self._asset_name = asset_name
         # stringvars and intvars
         self._strvar_target = tk.StringVar()
         self._strvar_owner = tk.StringVar()
@@ -32,7 +65,7 @@ class PublishingView(Viewable):
         # target project
         self._target_project = None
 
-    def _on_build(self):
+    def _build(self):
         self._body = tk.Toplevel()
         self._body.title("Publishing")
         self._body.resizable(0, 0)
@@ -70,15 +103,10 @@ class PublishingView(Viewable):
         # footer
         self._set_widgets_footer(self._body)
 
-    def _on_display(self):
+    def _on_map(self):
+        super()._on_map()
         self._populate()
 
-    def _on_destroy(self):
-        pass
-
-    def _toplevel_geometry(self):
-        tkmisc.center_window(self._body)
-        tkmisc.dialog_effect(self._body)
 
     # ====================================
     #               PRIVATE
@@ -175,10 +203,10 @@ class PublishingView(Viewable):
         frame = tk.Frame(parent)
         frame.grid(row=2, column=1, sticky="w")
         # label
-        label_archive_format = tk.Label(frame, text="Archive format")
+        label_archive_format = tk.Label(frame, text="Package format")
         label_archive_format.pack(anchor="w")
         # entry
-        strvar = tk.StringVar(value="zip")
+        strvar = tk.StringVar(value="Wheel")
         entry_archive_format = tk.Entry(frame, width=20,
                                         textvariable=strvar,
                                         state="readonly")
@@ -237,12 +265,18 @@ class PublishingView(Viewable):
         self.destroy()
 
     def _on_click_publishing(self):
+        message = ("\n\nSorry but Hubway isn't anymore the",
+                   "recommended way to publish your app.",
+                   "Please use the command 'publish' in",
+                   "the Pyrustic command-line tool Manager !\n\n")
+        Toast(self._body, message="\n".join(message), duration=20000)
+        return
         if not self._check_mandatory_field():
             return
         confirm = Confirm(self._body, title="Confirmation",
                           header="Ready to publish your project",
                           message="Do you want to continue ?")
-        confirm.build_wait()
+        confirm.wait_window()
         if not confirm.ok:
             return
         owner = self._strvar_owner.get()
@@ -250,14 +284,13 @@ class PublishingView(Viewable):
         name = self._strvar_release_name.get()
         tag_name = self._strvar_tag_name.get()
         target_commitish = self._strvar_target_commitish.get()
-        description = self._text_description.get("1.0","end-1c")
+        description = self._text_description.get("1.0", "end-1c")
         prerelease = True if self._intvar_prerelease.get() == 1 else False
         draft = True if self._intvar_draft.get() == 1 else False
         asset_name = self._strvar_asset_name.get()
         asset_label = self._strvar_asset_label.get()
-        self._asset_path = os.path.join(self._target_project,
-                                        "pyrustic_data", "dist",
-                                        "{}.zip".format(self._asset_version))
+        self._asset_path = os.path.join(self._target_project, "dist",
+                                        self._asset_name)
         # threadom stuff
         threadom = self._main_view.threadom
         host = self._main_host.publishing
@@ -265,19 +298,16 @@ class PublishingView(Viewable):
                      description, prerelease, draft,
                      self._asset_path, asset_name, asset_label)
         consumer = self._notify_publishing_response
-        threadom.run(host, args=host_args, consumer=consumer)
+        threadom.run(host, target_args=host_args, consumer=consumer)
         self._cache_toast_processing = Toast(self._body, message="Processing...",
                                              duration=None)
-        self._cache_toast_processing.build()
 
     def _check_mandatory_field(self):
         if self._strvar_repo.get() == "":
             toast = Toast(self._body, message="Please set the repository name")
-            toast.build()
             return False
         if self._strvar_tag_name.get() == "":
-            toast = Toast(self._body, message="Please set the tag name")
-            toast.build()
+            Toast(self._body, message="Please set the tag name")
             return False
         return True
 
@@ -286,7 +316,7 @@ class PublishingView(Viewable):
         data = self._main_host.about_target_project()
         target = data["target"]
         project_name = data["project_name"]
-        version = self._asset_version
+        version = self._main_host.get_asset_version(self._asset_name)
         owner = self._main_host.login
         default_target_commitish = "master"
         # target
@@ -300,9 +330,10 @@ class PublishingView(Viewable):
         # tag name
         self._strvar_tag_name.set("v{}".format(version))
         # release name
-        self._strvar_release_name.set("v{}".format(version))
+        self._strvar_release_name.set("{}/{} - v{}".format(owner,
+                                                         project_name, version))
         # asset name
-        cache = "{}-v{}-released-by-{}.zip".format(project_name, version, owner)
+        cache = self._asset_name
         self._strvar_asset_name.set(cache)
         # asset label
         self._strvar_asset_label.set("Download the release")
@@ -311,18 +342,10 @@ class PublishingView(Viewable):
         repo = self._strvar_repo.get()
         pyrustic_link = "https://github.com/pyrustic/pyrustic#readme"
         hubstore_link = "https://github.com/pyrustic/hubstore#readme"
-        cache = "Install [Hubstore]({}):\n\n".format(hubstore_link)
-        cache += "```bash\n"
-        cache += "$ pip install hubstore\n"
-        cache += "```\n\n"
-        cache += "Run Hubstore:\n\n"
-        cache += "```bash\n"
-        cache += "$ hubstore\n"
-        cache += "```\n\n"
-        cache += "Then paste/type this in Hubstore:\n`{}/{}`\n\n".format(owner, repo)
-        cache += "Enjoy !\n\n\n"
-        cache += "Packaged and released with [Pyrustic]({}).".format(pyrustic_link)
-        self._text_description.insert("1.0", cache)
+        text = TEXT.format(hubstore_link=hubstore_link,
+                           owner=owner, repo=repo,
+                           pyrustic_link=pyrustic_link)
+        self._text_description.insert("1.0", text)
 
     def _notify_publishing_response(self, data):
         if self._cache_toast_processing:
@@ -333,17 +356,12 @@ class PublishingView(Viewable):
         status_text = data["status_text"]
         message = "Successfully published"
         messages = {0: "Successfully published !",
-                    1: "Failed to cache the target project\n{}".format(data["data"]),
-                    2: "Tests failed\n{}".format(data["data"]),
-                    3: "Failed to execute prolog\n{}".format(data["data"]),
-                    4: "Failed to zip\n{}".format(data["data"]),
-                    5: "Failed to create release\n{}".format(status_text),
-                    6: "Failed to upload zip\n{}".format(status_text),
-                    7: "Failed to execute epilog\n{}".format(data["data"])}
+                    1: "Failed to create release\n{}".format(status_text),
+                    2: "Failed to upload asset\n{}".format(status_text)}
         message = messages[meta_code]
         if meta_code == 0:
             toast = Toast(self._body, message=message)
-            toast.build_wait()
+            toast.wait_window()
             data = (self._strvar_owner.get(), self._strvar_repo.get())
             self._main_view.central_view.add_node(*data)
             self.destroy()
